@@ -36,10 +36,9 @@ class EasySpreadsheet():
     def push(self):
         
         cell_list = []
-        for index, row in enumerate(wdf.to_dict(orient='records')):
+        for index, row in enumerate(self.table.to_dict(orient='records')):
             values = self._make_sheet_row(row.values())
 
-            
             for value_index, value in enumerate(values):
                 cell = gspread.models.Cell(index + 1, value_index + 1)
                 cell.value = value
